@@ -16,6 +16,7 @@ activer_accounting=$(CreoleGet activer_accounting)
 ## variables globales
 ##
 PROXY_PORTS="80,8080,443,3128"
+WEB_PORTS="80,443"
 FTP_PORTS="20,21"
 LDAP_PORTS="389,636"
 POP3_PORTS="110,995"
@@ -31,111 +32,122 @@ SSH_PORTS="22"
 #########################################
 # déclaration variables des dicos
 
-module_type=$(CreoleGet module_type amon)
-variante_type=$(CreoleGet variante_type essl)
- %if %%is_defined('type_amon')
-type_amon=$(CreoleGet type_amon 2zones-essl)
- %end if
- %if %%is_defined('serveurs_proxies_nationaux_ip')
+activer_firewall=$(CreoleGet activer_firewall non)
+  %if %%activer_firewall == 'oui'
+
+
+   %if %%is_defined('serveurs_proxies_nationaux_ip')
 serveurs_proxies_nationaux_ip=$(CreoleGet serveurs_proxies_nationaux_ip)
- %end if
- %if %%is_defined('serveurs_proxies_pro_ip')
+   %end if
+   %if %%is_defined('serveurs_proxies_pro_ip')
 serveurs_proxies_pro_ip=$(CreoleGet serveurs_proxies_pro_ip)
- %end if
- %if %%is_defined('serveurs_melanie2_nationaux_ip')
+   %end if
+   %if %%is_defined('serveurs_melanie2_nationaux_ip')
 serveurs_melanie2_nationaux_ip=$(CreoleGet serveurs_melanie2_nationaux_ip)
- %end if
- %if %%is_defined('serveurs_ldap_nationaux_ip')
+   %end if
+   %if %%is_defined('serveurs_ldap_nationaux_ip')
 serveurs_ldap_nationaux_ip=$(CreoleGet serveurs_ldap_nationaux_ip)
- %end if
- %if %%is_defined('serveurs_mcafee_nationaux_ip')
+   %end if
+   %if %%is_defined('serveurs_mcafee_nationaux_ip')
 serveurs_mcafee_nationaux_ip=$(CreoleGet serveurs_mcafee_nationaux_ip)
- %end if
- %if %%is_defined('serveurs_dns_nationaux_ip')
+   %end if
+   %if %%is_defined('serveurs_dns_nationaux_ip')
 serveurs_dns_nationaux_ip=$(CreoleGet serveurs_dns_nationaux_ip)
- %end if
- %if %%is_defined('serveurs_wsus_nationaux_ip')
+   %end if
+   %if %%is_defined('serveurs_wsus_nationaux_ip')
 serveurs_wsus_nationaux_ip=$(CreoleGet serveurs_wsus_nationaux_ip)
- %end if
+   %end if
+
+
+eth0=$(CreoleGet nom_carte_eth0)
+   %if %%is_defined('nom_carte_eth1')
+eth1=$(CreoleGet nom_carte_eth1)
+   %end if
+   %if %%is_defined('nom_carte_eth2')
+eth2=$(CreoleGet nom_carte_eth2)
+   %end if
+
 #########################################
 
-  %if %%is_defined('module_type')
-   %if %%module_type == 'amon'
 ## suppression de toutes les tables ipset
 ipset -X
 
 # proxies nationaux
-    %if %%is_defined('serveurs_proxies_nationaux_ip')
-     %if not %%is_empty(%%serveurs_proxies_nationaux_ip)
+   %if %%is_defined('serveurs_proxies_nationaux_ip')
+    %if not %%is_empty(%%serveurs_proxies_nationaux_ip)
 ipset -N proxies iphash --hashsize 32 --probes 1
-      %for %%proxy_iter in %%serveurs_proxies_nationaux_ip
+     %for %%proxy_iter in %%serveurs_proxies_nationaux_ip
 ipset -A proxies %%proxy_iter
-      %end for
-     %end if
+     %end for
     %end if
+   %end if
 
 # proxies pro
-    %if %%is_defined('serveurs_proxies_pro_ip')
-     %if not %%is_empty(%%serveurs_proxies_pro_ip)
+   %if %%is_defined('serveurs_proxies_pro_ip')
+    %if not %%is_empty(%%serveurs_proxies_pro_ip)
 ipset -N proxiespro iphash --hashsize 32 --probes 1
-      %for %%proxypro_iter in %%serveurs_proxies_pro_ip
+     %for %%proxypro_iter in %%serveurs_proxies_pro_ip
 ipset -A proxiespro %%proxypro_iter
-      %end for
-     %end if
+     %end for
     %end if
+   %end if
 
 # serveurs melanie2
-    %if %%is_defined('serveurs_melanie2_nationaux_ip')
-     %if not %%is_empty(%%serveurs_melanie2_nationaux_ip)
+   %if %%is_defined('serveurs_melanie2_nationaux_ip')
+    %if not %%is_empty(%%serveurs_melanie2_nationaux_ip)
 ipset -N melanie2  iphash --hashsize 32 --probes 1
-      %for %%melanie2_iter in %%serveurs_melanie2_nationaux_ip
+     %for %%melanie2_iter in %%serveurs_melanie2_nationaux_ip
 ipset -A melanie2 %%melanie2_iter
-      %end for
-     %end if
+     %end for
     %end if
+   %end if
 
 # serveurs LDAP
-    %if %%is_defined('serveurs_ldap_nationaux_ip')
-     %if not %%is_empty(%%serveurs_ldap_nationaux_ip)
+   %if %%is_defined('serveurs_ldap_nationaux_ip')
+    %if not %%is_empty(%%serveurs_ldap_nationaux_ip)
 ipset -N ldap iphash --hashsize 32 --probes 1
-      %for %%ldap_iter in %%serveurs_ldap_nationaux_ip
+     %for %%ldap_iter in %%serveurs_ldap_nationaux_ip
 ipset -A ldap %%ldap_iter
-      %end for
-     %end if
+     %end for
     %end if
+   %end if
 
 ## serveurs McAfee
-    %if %%is_defined('serveurs_mcafee_nationaux_ip')
-     %if not %%is_empty(%%serveurs_mcafee_nationaux_ip)
+   %if %%is_defined('serveurs_mcafee_nationaux_ip')
+    %if not %%is_empty(%%serveurs_mcafee_nationaux_ip)
 ipset -N mcafee iphash --hashsize 32 --probes 1
-      %for %%mcafee_iter in %%serveurs_mcafee_nationaux_ip
+     %for %%mcafee_iter in %%serveurs_mcafee_nationaux_ip
 ipset -A mcafee %%mcafee_iter
-      %end for
-     %end if
+     %end for
     %end if
+   %end if
 
 # serveurs dns
-    %if %%is_defined('serveurs_dns_nationaux_ip')
-     %if not %%is_empty(%%serveurs_dns_nationaux_ip)
+   %if %%is_defined('serveurs_dns_nationaux_ip')
+    %if not %%is_empty(%%serveurs_dns_nationaux_ip)
 ipset -N dns iphash --hashsize 32 --probes 1
-      %for %%dns_iter in %%serveurs_dns_nationaux_ip
+     %for %%dns_iter in %%serveurs_dns_nationaux_ip
 ipset -A dns %%dns_iter
-      %end for
-     %end if
+     %end for
     %end if
+   %end if
 
 # serveurs wsus national
-    %if %%is_defined('serveurs_wsus_nationaux_ip')
-     %if not %%is_empty(%%serveurs_wsus_nationaux_ip)
+   %if %%is_defined('serveurs_wsus_nationaux_ip')
+    %if not %%is_empty(%%serveurs_wsus_nationaux_ip)
 ipset -N wsus iphash --hashsize 32 --probes 1
-      %for %%wsus_iter in %%serveurs_wsus_nationaux_ip
+     %for %%wsus_iter in %%serveurs_wsus_nationaux_ip
 ipset -A wsus %%wsus_iter
-      %end for
-     %end if
+     %end for
     %end if
+   %end if
 
-
-
+module_type=$(CreoleGet module_type amon)
+variante_type=$(CreoleGet variante_type essl)
+   %if %%module_type == 'amon'
+    %if %%is_defined('type_amon')
+    type_amon=$(CreoleGet type_amon 2zones-essl)
+    %end if
 ########################################################################
 ###              Gestion du traffic par ports                        ###
 ########################################################################
@@ -150,9 +162,9 @@ ipset -A wsus %%wsus_iter
 
     %if %%type_amon == '2zones-essl'
 ################### Flux Proxy/DNS/Anti-virus ##########################
-# Ports eSSL depuis/vers MOREA
-/sbin/iptables -I OUTPUT -o eth1 -m comment --comment "ACC-ports_out-morea" -j ports_essl_OUT
-/sbin/iptables -I INPUT -i eth1 -m comment --comment "ACC-ports_in-morea" -j ports_essl_IN
+# Ports eSSL depuis/vers le Wan
+/sbin/iptables -I OUTPUT -o $eth1 -m comment --comment "ACC-ports_out-morea" -j ports_essl_OUT
+/sbin/iptables -I INPUT -i $eth1 -m comment --comment "ACC-ports_in-morea" -j ports_essl_IN
 
 # ** Protocoles Proxy **
 /sbin/iptables -A ports_essl_IN -p tcp -m multiport --dport $PROXY_PORTS -m comment --comment "ACC-ports_in-proxies-http"
@@ -164,15 +176,17 @@ ipset -A wsus %%wsus_iter
 #** Protocole DNS **
 /sbin/iptables -A ports_essl_IN -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_in-dns-clients"
 /sbin/iptables -A ports_essl_OUT -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_out-dns-clients"
+/sbin/iptables -A ports_essl_IN -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_in-dns-clients"
+/sbin/iptables -A ports_essl_OUT -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_out-dns-clients"
 #** Protocole SSH **
 /sbin/iptables -A ports_essl_IN -p tcp -m multiport --dport $SSH_PORTS -m comment --comment "ACC-ports_in-ssh-clients"
 /sbin/iptables -A ports_essl_OUT -p tcp -m multiport --dport $SSH_PORTS -m comment --comment "ACC-ports_out-ssh-clients"
 
-     %if %%variante_type == 'eSSL Internet'
+     %if %%variante_type == 'eSSL_Internet'
 ################### Flux Proxy/DNS/antivirus Internet ##################################
 # Flux eSSL depuis/vers INTERNET
-/sbin/iptables -I OUTPUT -o eth0 -m comment --comment "ACC-ports_out-internet" -j ports_essl_OUT
-/sbin/iptables -I INPUT -i eth0 -m comment --comment "ACC-ports_in-internet" -j ports_essl_IN
+/sbin/iptables -I OUTPUT -o $eth0 -m comment --comment "ACC-ports_out-internet" -j ports_essl_OUT
+/sbin/iptables -I INPUT -i $eth0 -m comment --comment "ACC-ports_in-internet" -j ports_essl_IN
 
 # ** Protocoles Proxy **
 /sbin/iptables -A ports_essl_IN -p tcp -m multiport --sport $PROXY_PORTS -m comment --comment "ACC-ports_INTERNET_in-proxies-http"
@@ -183,15 +197,17 @@ ipset -A wsus %%wsus_iter
 #** Protocole DNS **
 /sbin/iptables -A ports_essl_IN -p tcp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_INTERNET_in-dns-clients"
 /sbin/iptables -A ports_essl_OUT -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_INTERNET_out-dns-clients"
+/sbin/iptables -A ports_essl_IN -p udp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_INTERNET_in-dns-clients"
+/sbin/iptables -A ports_essl_OUT -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_INTERNET_out-dns-clients"
      %end if
 
     %else
 ################### Flux Proxy/DNS/Anti-virus ##########################
-# Ports eSSL LAN <--> MOREA
-/sbin/iptables -I OUTPUT -o eth1 -m comment --comment "ACC-ports_out-morea" -j ports_essl_OUT
-/sbin/iptables -I INPUT -i eth1 -m comment --comment "ACC-ports_in-morea" -j ports_essl_IN
-/sbin/iptables -I OUTPUT -o eth2 -m comment --comment "ACC-ports_out-lan" -j ports_essl_lan_OUT
-/sbin/iptables -I INPUT -i eth2 -m comment --comment "ACC-ports_in-lan" -j ports_essl_lan_IN
+# Ports eSSL LAN <--> WAN
+/sbin/iptables -I OUTPUT -o $eth1 -m comment --comment "ACC-ports_out-morea" -j ports_essl_OUT
+/sbin/iptables -I INPUT -i $eth1 -m comment --comment "ACC-ports_in-morea" -j ports_essl_IN
+/sbin/iptables -I OUTPUT -o $eth2 -m comment --comment "ACC-ports_out-lan" -j ports_essl_lan_OUT
+/sbin/iptables -I INPUT -i $eth2 -m comment --comment "ACC-ports_in-lan" -j ports_essl_lan_IN
 
 # ** Protocoles Proxy **
 /sbin/iptables -A ports_essl_IN -p tcp -m multiport --dport $PROXY_PORTS -m comment --comment "ACC-ports_in-proxies-http"
@@ -211,6 +227,10 @@ ipset -A wsus %%wsus_iter
 /sbin/iptables -A ports_essl_OUT -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_out-dns-clients"
 /sbin/iptables -A ports_essl_lan_IN -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_in_LAN-dns-clients"
 /sbin/iptables -A ports_essl_lan_OUT -p tcp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_out_LAN-dns-clients"
+/sbin/iptables -A ports_essl_IN -p udp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_in-dns-clients"
+/sbin/iptables -A ports_essl_OUT -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_out-dns-clients"
+/sbin/iptables -A ports_essl_lan_IN -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_in_LAN-dns-clients"
+/sbin/iptables -A ports_essl_lan_OUT -p udp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_out_LAN-dns-clients"
 #** Protocole SSH **
 /sbin/iptables -A ports_essl_IN -p tcp -m multiport --sport $SSH_PORTS -m comment --comment "ACC-ports_in-ssh-clients"
 /sbin/iptables -A ports_essl_OUT -p tcp -m multiport --dport $SSH_PORTS -m comment --comment "ACC-ports_out-ssh-clients"
@@ -220,9 +240,9 @@ ipset -A wsus %%wsus_iter
 
 ###########################################################################
 ################### Flux Pare-feu #########################################
-# Ports pare-feu depuis/vers MOREA
-/sbin/iptables -I FORWARD -o eth1 -m comment --comment "ACC-ports_PF_out-morea" -j ports_forward_OUT
-/sbin/iptables -I FORWARD -i eth1 -m comment --comment "ACC-ports_PF_in-morea" -j ports_forward_IN
+# Ports pare-feu depuis/vers le Wan
+/sbin/iptables -I FORWARD -o $eth1 -m comment --comment "ACC-ports_PF_out-morea" -j ports_forward_OUT
+/sbin/iptables -I FORWARD -i $eth1 -m comment --comment "ACC-ports_PF_in-morea" -j ports_forward_IN
 
 # ** Protocoles Proxy **
 /sbin/iptables -A ports_forward_IN -p tcp -m multiport --sport $PROXY_PORTS -m comment --comment "ACC-ports_PF_in-proxies-http"
@@ -233,6 +253,8 @@ ipset -A wsus %%wsus_iter
 #** Protocole DNS **
 /sbin/iptables -A ports_forward_IN -p tcp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_PF_in-dns-clients"
 /sbin/iptables -A ports_forward_OUT -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_PF_out-dns-clients"
+/sbin/iptables -A ports_forward_IN -p udp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_PF_in-dns-clients"
+/sbin/iptables -A ports_forward_OUT -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_PF_out-dns-clients"
 # ** Protocoles Melanie2 **
 /sbin/iptables -A ports_forward_IN -p tcp -m multiport --sport $POP3_PORTS -m comment --comment "ACC-ports_PF_in-melanie2-pop"
 /sbin/iptables -A ports_forward_IN -p tcp -m multiport --sport $SMTP_PORTS -m comment --comment "ACC-ports_PF_in-melanie2-smtp"
@@ -250,12 +272,14 @@ ipset -A wsus %%wsus_iter
 # ** Protocoles NetBios **
 /sbin/iptables -A ports_forward_IN -p tcp -m multiport --sport $SAMBA_PORTS -m comment --comment "ACC-ports_PF_in-samba-clients"
 /sbin/iptables -A ports_forward_OUT -p tcp -m multiport --dport $SAMBA_PORTS -m comment --comment "ACC-ports_PF_out-samba-clients"
+/sbin/iptables -A ports_forward_IN -p udp -m multiport --sport $SAMBA_PORTS -m comment --comment "ACC-ports_PF_in-samba-clients"
+/sbin/iptables -A ports_forward_OUT -p udp -m multiport --dport $SAMBA_PORTS -m comment --comment "ACC-ports_PF_out-samba-clients"
 
-     %if %%variante_type == 'eSSL Internet'
+     %if %%variante_type == 'eSSL_Internet'
 ################### Flux Proxy Internet ##################################
 # Flux eSSL depuis/vers INTERNET
-/sbin/iptables -I OUTPUT -o eth0 -m comment --comment "ACC-ports_out-internet" -j ports_essl_OUT
-/sbin/iptables -I INPUT -i eth0 -m comment --comment "ACC-ports_in-internet" -j ports_essl_IN
+/sbin/iptables -I OUTPUT -o $eth0 -m comment --comment "ACC-ports_out-internet" -j ports_essl_OUT
+/sbin/iptables -I INPUT -i $eth0 -m comment --comment "ACC-ports_in-internet" -j ports_essl_IN
 
 # ** Protocoles Proxy **
 /sbin/iptables -A ports_essl_IN -p tcp -m multiport --sport $PROXY_PORTS -m comment --comment "ACC-ports_INTERNET_in-proxies-http"
@@ -266,11 +290,13 @@ ipset -A wsus %%wsus_iter
 #** Protocole DNS **
 /sbin/iptables -A ports_essl_IN -p tcp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_INTERNET_in-dns-clients"
 /sbin/iptables -A ports_essl_OUT -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_INTERNET_out-dns-clients"
+/sbin/iptables -A ports_essl_IN -p udp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_INTERNET_in-dns-clients"
+/sbin/iptables -A ports_essl_OUT -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_INTERNET_out-dns-clients"
 
 ################### Flux Pare-feu Internet #########################################
 # Ports pare-feu depuis/vers INTERNET
-/sbin/iptables -I FORWARD -o eth0 -m comment --comment "ACC-ports_PF_out-internet" -j ports_forward_OUT
-/sbin/iptables -I FORWARD -i eth0 -m comment --comment "ACC-ports_PF_in-internet" -j ports_forward_IN
+/sbin/iptables -I FORWARD -o $eth0 -m comment --comment "ACC-ports_PF_out-internet" -j ports_forward_OUT
+/sbin/iptables -I FORWARD -i $eth0 -m comment --comment "ACC-ports_PF_in-internet" -j ports_forward_IN
 
 # ** Protocoles Proxy **
 /sbin/iptables -A ports_forward_IN -p tcp -m multiport --sport $PROXY_PORTS -m comment --comment "ACC-ports_PF_INTERNET_in-proxies-http"
@@ -281,6 +307,8 @@ ipset -A wsus %%wsus_iter
 #** Protocole DNS **
 /sbin/iptables -A ports_forward_IN -p tcp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_PF_INTERNET_in-dns-clients"
 /sbin/iptables -A ports_forward_OUT -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_PF_INTERNET_out-dns-clients"
+/sbin/iptables -A ports_forward_IN -p udp -m multiport --sport $DNS_PORTS -m comment --comment "ACC-ports_PF_INTERNET_in-dns-clients"
+/sbin/iptables -A ports_forward_OUT -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_PF_INTERNET_out-dns-clients"
      %end if
     %end if
 
@@ -297,9 +325,9 @@ ipset -A wsus %%wsus_iter
 /sbin/iptables -N flux_essl_OUT
 
 ################### Flux Proxy/DNS/Anti-virus #############################
-# Flux eSSL depuis/vers MOREA
-/sbin/iptables -I OUTPUT -o eth1 -m comment --comment "ACC-flux_out-morea" -j flux_essl_OUT
-/sbin/iptables -I INPUT -i eth1 -m comment --comment "ACC-flux_in-morea" -j flux_essl_IN
+# Flux eSSL depuis/vers le Wan
+/sbin/iptables -I OUTPUT -o $eth1 -m comment --comment "ACC-flux_out-morea" -j flux_essl_OUT
+/sbin/iptables -I INPUT -i $eth1 -m comment --comment "ACC-flux_in-morea" -j flux_essl_IN
 
 # Flux Morea serveurs proxies nationaux
     %if %%is_defined('serveurs_proxies_nationaux_ip')
@@ -334,9 +362,9 @@ ipset -A wsus %%wsus_iter
     %if %%type_amon != '2zones-essl'
 ###########################################################################
 ################### Flux Pare-feu #########################################
-# Flux pare-feu depuis/vers MOREA
-/sbin/iptables -I FORWARD -o eth1 -m comment --comment "ACC-flux_out-morea" -j flux_forward_OUT
-/sbin/iptables -I FORWARD -i eth1 -m comment --comment "ACC-flux_in-morea" -j flux_forward_IN
+# Flux pare-feu depuis/vers le Wan
+/sbin/iptables -I FORWARD -o $eth1 -m comment --comment "ACC-flux_out-morea" -j flux_forward_OUT
+/sbin/iptables -I FORWARD -i $eth1 -m comment --comment "ACC-flux_in-morea" -j flux_forward_IN
 
 # Flux Morea serveurs proxies nationaux
      %if %%is_defined('serveurs_proxies_nationaux_ip')
@@ -389,9 +417,101 @@ ipset -A wsus %%wsus_iter
      %end if
     %end if
 
+    %elif %%module_type in ('eSBL', 'eCDL')
+########################################################################
+###              Gestion du traffic par ports                        ###
+########################################################################
+# Declaration des chaines internes 'ports'
+/sbin/iptables -N ports_IN
+/sbin/iptables -N ports_OUT
+
+# Flux globaux entrée/sortie eSBL-eCDL
+/sbin/iptables -I OUTPUT -o $eth0 -m comment --comment "ACC-ports_out-total" -j ports_OUT
+/sbin/iptables -I INPUT -i $eth0 -m comment --comment "ACC-ports_in-total" -j ports_IN
+
+# ** Protocoles Proxy **
+/sbin/iptables -A ports_IN -p tcp -m multiport --sport $PROXY_PORTS -m comment --comment "ACC-ports_in-proxies"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $PROXY_PORTS -m comment --comment "ACC-ports_out-proxies"
+# ** Protocoles WEB **
+/sbin/iptables -A ports_IN -p tcp -m multiport --dport $WEB_PORTS -m comment --comment "ACC-ports_in-web"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $WEB_PORTS -m comment --comment "ACC-ports_out-web"
+# ** Protocoles FTP **
+/sbin/iptables -A ports_IN -p tcp -m multiport --dport $FTP_PORTS -m comment --comment "ACC-ports_in-ftp"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $FTP_PORTS -m comment --comment "ACC-ports_out-ftp"
+#** Protocole DNS **
+/sbin/iptables -A ports_IN -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_in-dns-clients"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_out-dns-clients"
+/sbin/iptables -A ports_IN -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_in-dns-clients"
+/sbin/iptables -A ports_OUT -p udp -m multiport --dport $DNS_PORTS -m comment --comment "ACC-ports_out-dns-clients"
+#** Protocole SSH **
+/sbin/iptables -A ports_IN -p tcp -m multiport --dport $SSH_PORTS -m comment --comment "ACC-ports_in-ssh-clients"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $SSH_PORTS -m comment --comment "ACC-ports_out-ssh-clients"
+# ** Protocoles Melanie2 **
+/sbin/iptables -A ports_IN -p tcp -m multiport --sport $POP3_PORTS -m comment --comment "ACC-ports_in-melanie2-pop"
+/sbin/iptables -A ports_IN -p tcp -m multiport --sport $SMTP_PORTS -m comment --comment "ACC-ports_in-melanie2-smtp"
+/sbin/iptables -A ports_IN -p tcp -m multiport --sport $IMAP_PORTS -m comment --comment "ACC-ports_in-melanie2-imap"
+/sbin/iptables -A ports_IN -p tcp -m multiport --sport $LDAP_PORTS -m comment --comment "ACC-ports_in-melanie2-ldap(s)"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $POP3_PORTS -m comment --comment "ACC-ports_out-melanie2-pop"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $SMTP_PORTS -m comment --comment "ACC-ports_out-melanie2-smtp"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $IMAP_PORTS -m comment --comment "ACC-ports_out-melanie2-imap"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $LDAP_PORTS -m comment --comment "ACC-ports_out-melanie2-ldap(s)"
+# ** Protocoles  McAfee **
+/sbin/iptables -A ports_IN -p tcp -m multiport --sport $MCAFEE_PORTS -m comment --comment "ACC-ports_in-mcafee-clients"
+/sbin/iptables -A ports_IN -p tcp --sport $MCAFEE_EPO -m comment --comment "ACC-ports_in-mcafee-epo"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $MCAFEE_PORTS -m comment --comment "ACC-ports_out-mcafee-clients"
+/sbin/iptables -A ports_OUT -p tcp --dport $MCAFEE_EPO -m comment --comment "ACC-ports_out-mcafee-epo"
+# ** Protocoles NetBios **
+/sbin/iptables -A ports_IN -p tcp -m multiport --dport $SAMBA_PORTS -m comment --comment "ACC-ports_in-samba-clients"
+/sbin/iptables -A ports_OUT -p tcp -m multiport --dport $SAMBA_PORTS -m comment --comment "ACC-ports_out-samba-clients"
+/sbin/iptables -A ports_IN -p udp -m multiport --dport $SAMBA_PORTS -m comment --comment "ACC-ports_in-samba-clients"
+/sbin/iptables -A ports_OUT -p udp -m multiport --dport $SAMBA_PORTS -m comment --comment "ACC-ports_out-samba-clients"
+
+########################################################################
+###            Gestion du traffic par Serveurs Nationaux             ###
+########################################################################
+#######################################################
+# Declaration des chaines internes 'flux'
+/sbin/iptables -N flux_IN
+/sbin/iptables -N flux_OUT
+
+# Flux depuis/vers serveurs nationaux
+/sbin/iptables -I OUTPUT -o $eth0 -m comment --comment "ACC-flux_out-total" -j flux_OUT
+/sbin/iptables -I INPUT -i $eth0 -m comment --comment "ACC-flux_in-total" -j flux_IN
+
+# Flux serveurs proxies nationaux
+    %if %%is_defined('serveurs_proxies_nationaux_ip')
+     %if not %%is_empty(%%serveurs_proxies_nationaux_ip)
+/sbin/iptables -A flux_OUT -m set --match-set  proxies dst -m comment --comment "ACC-flux_out-proxies"
+/sbin/iptables -A flux_IN -m set --match-set  proxies src -m comment --comment "ACC-flux_in-proxies"
+     %end if
+    %end if
+#Flux serveurs LDAP
+    %if %%is_defined('serveurs_ldap_nationaux_ip')
+     %if not %%is_empty(%%serveurs_ldap_nationaux_ip)
+/sbin/iptables -A flux_OUT -m set --match-set ldap dst -m comment --comment "ACC-flux_out-ldap"
+/sbin/iptables -A flux_IN -m set --match-set ldap src -m comment --comment "ACC-flux_in-ldap"
+     %end if
+    %end if
+# Flux serveurs McAfee
+    %if %%is_defined('serveurs_mcafee_nationaux_ip')
+     %if not %%is_empty(%%serveurs_mcafee_nationaux_ip)
+/sbin/iptables -A flux_OUT -m set --match-set mcafee dst -m comment --comment "ACC-flux_out-mcafee"
+/sbin/iptables -A flux_IN -m set --match-set mcafee src -m comment --comment "ACC-flux_in-mcafee"
+     %end if
+    %end if
+#Flux serveurs dns nationaux
+    %if %%is_defined('serveurs_dns_nationaux_ip')
+     %if not %%is_empty(%%serveurs_dns_nationaux_ip)
+/sbin/iptables -A flux_OUT -m set --match-set dns dst -m comment --comment "ACC-flux_out-dnsnat"
+/sbin/iptables -A flux_IN -m set --match-set dns src -m comment --comment "ACC-flux_in-dnsnat"
+     %end if
+    %end if
+
    %else
-# eSBL ou eCDL, acounting non disponible
+# Module inconnu
    %end if
+  %else
+# Pare-feu non activé
   %end if
 ##########################################################################
  %else
